@@ -4,7 +4,7 @@ use 5.006001;
 use strict;
 use warnings;
 
-our $VERSION = '0.05';
+our $VERSION = '0.06';
 
 sub new{
   my ($class) = @_;
@@ -25,7 +25,7 @@ sub find{
     $text =~ s,<<'(.*?)'.*?\n\1,,sg;
     $text =~ s,'.*?',,sg;
     $text =~ s,q~.*?~,,sg;
-    @array = $text =~ m/(?:(\$\w+(?:->)?(?:\[\$?\w+\]|{\$?\w+}))|(\${\w+})|(\$\w+))/sg;
+    @array = $text =~ m/(?:(\$\w+(?:->)?(?:\[\$?\w+\]|\{\$?\w+\}))|(\$\{\w+\})|(\$\w+))/sg;
     @array = grep{defined}@array;
   }
   $self->_Elements(@array);
@@ -80,12 +80,18 @@ sub _Elements{
 }# _Elements
 
 1;
-__END__
-# Below is stub documentation for your module. You'd better edit it!
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Text::Find::Scalar - Find scalar names in a text.
+Text::Find::Scalar
+
+=head1 VERSION
+
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -119,7 +125,6 @@ Scalars that should be found:
 
   $foo->{bar}
 
-
 =item * elements of arrays
 
   $array[0]
@@ -138,6 +143,10 @@ Scalars that are not covered
 
 =back
 
+=head1 NAME
+
+Text::Find::Scalar - Find scalar names in a text.
+
 =head1 EXAMPLE
 
   #!/usr/bin/perl
@@ -229,5 +238,19 @@ This library is free software; you can redistribute it and/or modify
 it under the same terms as Perl itself, either Perl version 5.8.6 or,
 at your option, any later version of Perl 5 you may have available.
 
+=head1 AUTHOR
+
+Renee Baecker <reneeb@cpan.org>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Renee Baecker.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
+
+__END__
+# Below is stub documentation for your module. You'd better edit it!
+
